// Touch screen library with X Y and Z (pressure) readings as well
// as oversampling to avoid 'bouncing'
// This demo code returns raw readings, public domain

#include <stdint.h>

// Touchscreen pins: Looks like pins are (counting from 1, red tape is 5-8)
// X == 3, 4    ?
// Y == 5, 8

#define X1 A5
#define X3 A4
#define X4 A3
#define Y5 A2
#define Y8 A1

const uint8_t XPINS[] = {X1, X3, X4};
const uint8_t XPIN_COUNT = 3;
const uint8_t YPINS[] = {Y5, Y8};
const uint8_t YPIN_COUNT = 2;

void setup(void) {
	Serial.begin(9600);
}

void loop(void) {
	// Read X position
	for (uint8_t i=0; i<XPIN_COUNT; i++) {
		pinMode(XPINS[i], OUTPUT);
		digitalWrite(XPINS[i], (XPINS[i]==X3) ? LOW : HIGH);
	}
	for (uint8_t i=0; i<YPIN_COUNT; i++) {
		pinMode(YPINS[i], INPUT);
		// Activate pullup resistors
		digitalWrite(YPINS[i], HIGH);
	}

	uint16_t y5 = analogRead(Y5);
	uint16_t y8 = analogRead(Y8);
	uint16_t xx = (y5 + y8) >> 1;

  // Read Y position
	for (uint8_t i=0; i<YPIN_COUNT; i++) {
		pinMode(YPINS[i], OUTPUT);
		digitalWrite(YPINS[i], (i==0) ? LOW : HIGH);
	}
	for (uint8_t i=0; i<XPIN_COUNT; i++) {
		pinMode(XPINS[i], INPUT);
		// Activate pullup resistors
		digitalWrite(XPINS[i], HIGH);
	}

	uint16_t x1 = analogRead(X1);
	uint16_t x3 = analogRead(X3);
	uint16_t x4 = analogRead(X4);
	uint16_t yy = (x1 + x3 + x4) / 3;

  // Infer pressure ("z" position).
  // Set X3 to LOW, Y5 to HIGH.
  pinMode(X3, OUTPUT);
  digitalWrite(X3, LOW);
  pinMode(Y5, OUTPUT);
  digitalWrite(Y5, HIGH);

  // Activate inputs with pull-up/pull-down resistors on X+ and Y+.
  // X1 and X4 are already inputs.
  pinMode(y8, INPUT);
  digitalWrite(y8, LOW);

  // The more their analogRead()'s differ from X- and Y-, the more pressure is being applied.
  uint16_t z14 = (analogRead(X1) + analogRead(X4)) >> 1;
  uint16_t z8 = analogRead(Y8);

  // Borrowed this formula from Adafruit's "TouchScreen" library. I'm not sure how this works?
  // When pressing, I'm getting lowest Z values in upper-right corner (~230),
  // highest in lower-right (~650), with occasional spikes around 1000.
  // When not pressing: Idles around ~60. Values >100 probably indicate a touch.
  uint16_t zz = 1024 - (z8 - z14);

	Serial.print("X:");
	Serial.print(xx);
	Serial.print(" Y:");
	Serial.print(yy);
	Serial.print(" Z:");
	Serial.println(zz);

	delay(400);
}
